#' Cancer classification
#'
#' A three factor level variable corresponding to cancer type
#'
#' @docType data
#'
#' @usage data(cancer)
#'
#' @format factor level with three levels
#' \describe{
#'   \item{cancer}{factor with cancer type}
#' }
#' @examples
#' data(cancer)
"cancer"


#' miRNA 
#'
#' A three factor level variable corresponding to cancer type 
#'
#' @docType data
#'
#' @usage data(miRNA)
#'
#' @format Dataframe with 21 samples and 537 variables
#' \describe{
#'   \item{columns}{variables}
#'   \item{rows}{samples}
#' }
#' @examples
#' data(miRNA)
"miRNA"

#' Dataset colesterol
#'
#' This dataset contains a dummy data for import dataset example
#'
#' @name colesterol
#'
#' @section colesterol.csv:
#'
#' This data is used in bdImportTextFile_hdf5() function.
NULL

NULL